/* Template for the Solution of Exercise 3 - Numerics of Transport in Porous Media

   This implements the assembler class to set up the system matrix of
   the cell centered finite volume discretization of the groundwater
   flow problem.

   This implementation makes use of the LGPL library libconfig which
   has to be available in order to compile this header file.

   Furthermore it requires implementations of the classes implemented
   in exercise 1 and 2 assumed within the header files
   DenseMatrix.hh, Vector.hh, grid.hh, and spatial_parameters.hh. 
   Additionally it requires an implementation of the BoundaryCondtions class 
   providing the boundary conditions at given coordinates.
*/

#ifndef GW_ASSEMBLER_HH
#define GW_ASSEMBLER_HH

#define DIMENSIONS 2
#include "Vector.hh"
#include "DenseMatrix.hh"
#include "grid.hh"
#include "spatial_parameters.hh"
#include "gw_bc.hh"

// Default values for the precompiler macros

// default matrix is full matrix
#ifndef MATRIXTYPE
#define MATRIXTYPE DenseMatrix
#endif


typedef SpatialParameters ConductivityCoefficients;

class GroundwaterAssembler
{
  const Grid & grid_;
  typedef SpatialParameters ConductivityCoefficients;
  const ConductivityCoefficients & conductivity_;
  const Sources & sources_;
  const BoundaryConditions & boundary_conditions_;

public:
  typedef MATRIXTYPE Matrix;

  GroundwaterAssembler(const Grid & _grid, 
		       const ConductivityCoefficients & _conductivity,
		       const Sources & _sources,
		       const BoundaryConditions & _boundary_conditions)
    : grid_(_grid), 
      conductivity_(_conductivity), 
      sources_(_sources), 
      boundary_conditions_(_boundary_conditions)
  {}

  void assemble(Matrix & A, Vector & b)
  {
	// INSERT YOUR CODE HERE!
  }
};

#endif // GW_ASSEMBLER_HH
